@@ -33,7 +33,7 @@ def create_arunner(coro_or_func: Function,
     :return:
     """
     return runner_factory(
-        AbstractRunner,
+        AsyncRunner,
         coro_or_func=coro_or_func,
         args=args,
         kwargs=kwargs,
